searchData={"items":[{"type":"module","title":"Exto","doc":"Configuration-driven Ecto Schemata.","ref":"Exto.html"},{"type":"macro","title":"Exto.flex_schema/1","doc":"Adds additional associations dynamically from app config.\n\nReads config for the given OTP application, under the name of the\ncurrent module. Each key maps to an Ecto.Schema function:\n\n* `belongs_to`\n* `field`\n* `has_many`\n* `has_one`\n* `many_to_many`\n\nEach of these keys should map to a keyword list where the key is the\nname of the field or association and the value is one of:\n\n* A type\n* A tuple of type and options (keyword list)\n\nExample Schema:\n\n```\ndefmodule My.Schema do\n  use Ecto.Schema\n  import Exto, only: [flex_schema: 1]\n\n  schema \"my_table\" do\n    field :name, :string # just normal schema things\n    flex_schema(:my_app) # boom! give me the stuff\n  end\nend\n```\n\nExample configuration:\n\n```\nconfig :my_app, My.Schema,\n  belongs_to: [\n    foo: Foo,                   # belongs_to :foo, Foo\n    bar: {Bar, type: :integer}, # belongs_to :bar, Bar, type: :integer\n  ],\n  field: [\n    foo: :string,                # field :foo, :string\n    bar: {:integer, default: 4}, # field :foo, :integer, default: 4\n  ],\n  has_one: [\n    foo: Foo,                             # has_one :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_one :bar, Bar, foreign_key: :the_bar_id\n  ]\n  has_many: [\n    foo: Foo,                             # has_many :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_many :bar, Bar, foreign_key: :the_bar_id\n  ]\n  many_to_many: [\n    foo: Foo,                         # many_to_many :foo, Foo\n    bar: {Bar, join_through: FooBar}, # many_to_many :bar, Bar, :join_through: FooBar\n  ]\n```\n\nThis one won't work very well because we define `foo` and `bar` 5\ntimes each, but I think you get the point.\n\nReading of configuration is done during compile time. The relations\nwill be baked in during compilation, thus:\n\n* Do not expect this to work in runtime config.\n* You will need to rebuild all dependencies which use this macro\n  when you change their configuration.","ref":"Exto.html#flex_schema/1"},{"type":"extras","title":"Exto","doc":"# Exto\n\n[![hex.pm](https://img.shields.io/hexpm/v/exto)](https://hex.pm/packages/exto)\n[hexdocs](https://hexdocs.pm/exto)\n\n`Exto` provides configuration-driven Ecto schema extensibility","ref":"readme.html"},{"type":"extras","title":"Usage - Exto","doc":"Example Schema:\n\n```elixir\ndefmodule My.Schema do\n  use Ecto.Schema\n  import Exto, only: [flex_schema: 1]\n\n  schema \"my_table\" do\n    field :name, :string # just normal schema things\n    flex_schema(:my_app) # boom! give me the stuff\n  end\nend\n```\n\nExample configuration\n\n```elixir\nconfig :my_app, My.Schema,\n  belongs_to: [\n    foo: Foo,                   # belongs_to :foo, Foo\n    bar: {Bar, type: :integer}, # belongs_to :bar, Bar, type: :integer\n  ],\n  field: [\n    foo: :string,                # field :foo, :string\n    bar: {:integer, default: 4}, # field :foo, :integer, default: 4\n  ],\n  has_one: [\n    foo: Foo,                             # has_one :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_one :bar, Bar, foreign_key: :the_bar_id\n  ]\n  has_many: [\n    foo: Foo,                             # has_many :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_many :bar, Bar, foreign_key: :the_bar_id\n  ]\n  many_to_many: [\n    foo: Foo,                         # many_to_many :foo, Foo\n    bar: {Bar, join_through: FooBar}, # many_to_many :bar, Bar, :join_through: FooBar\n  ]\n```\n\n  This one won't work very well because we define `foo` and `bar` 5\n  times each, but I think you get the point.\n\n  Reading of configuration is done during compile time. The relations\n  will be baked in during compilation, thus:\n\n  * Do not expect this to work in runtime config.\n  * You will need to rebuild all dependencies which use this macro\n    when you change their configuration.","ref":"readme.html#usage"},{"type":"extras","title":"Copyright and License - Exto","doc":"Copyright (c) 2020 Exto Contributors\n\n Licensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n   http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}